[inherit('common', 'psqlite', 'sqlite')]
program test(input, output);

procedure checkcon(con : sqlite_ptr);

begin
   if con = 0 then begin
      writeln('Error opening database file');
      halt;
   end;
end;

procedure checkstmt(stmt : sqlite_stmt_ptr; con : sqlite_ptr);

begin
   if stmt = 0 then begin
      writeln(psqlite_errmsg(con));
      halt;
   end;
end;

procedure checkstat(stat : boolean; con : sqlite_ptr);

begin
   if not stat then begin
      writeln(psqlite_errmsg(con));
      halt;
   end;
end;

function connect(fnm : pstr) : sqlite_ptr;

var
   con : sqlite_ptr;

begin
   con := psqlite_open(fnm);
   checkcon(con);
   connect := con;
end;

procedure test_getone(con : sqlite_ptr; f1 : integer);

var
   stmt : sqlite_stmt_ptr;
   stat : boolean;
   f2 : pstr;

begin
   stmt := psqlite_prepare(con, 'SELECT f2 FROM t1 WHERE f1 = ?');
   checkstmt(stmt, con);
   stat := psqlite_bind_int(stmt, 1, f1);
   checkstat(stat, con);
   if psqlite_step_query(stmt) then begin
      f2 := psqlite_column_text(stmt, 0);
      writeln(f2);
   end;
   psqlite_finalize(stmt);
end;

procedure test_getall(con : sqlite_ptr);

var
   stmt : sqlite_stmt_ptr;
   stat : boolean;
   f1 : integer;
   f2 : pstr;

begin
   stmt := psqlite_prepare(con, 'SELECT f1,f2 FROM t1');
   checkstmt(stmt, con);
   while psqlite_step_query(stmt) do begin
      f1 := psqlite_column_int(stmt, 0);
      f2 := psqlite_column_text(stmt, 1);
      writeln(f1, ' ', f2);
   end;
   psqlite_finalize(stmt);
end;

procedure test_insert(con : sqlite_ptr; f1 : integer; f2 : pstr);

var
   stmt : sqlite_stmt_ptr;
   stat : boolean;

begin
   stmt := psqlite_prepare(con, 'INSERT INTO t1 VALUES(?, ?)');
   checkstmt(stmt, con);
   stat := psqlite_bind_int(stmt, 1, f1);
   checkstat(stat, con);
   stat := psqlite_bind_text(stmt, 2, f2);
   checkstat(stat, con);
   stat := psqlite_step_nonquery(stmt);
   checkstat(stat, con);
   psqlite_finalize(stmt);
end;

procedure test_delete(con : sqlite_ptr; f1 : integer);

var
   stmt : sqlite_stmt_ptr;
   stat : boolean;

begin
   stmt := psqlite_prepare(con, 'DELETE FROM t1 WHERE f1 = ?');
   checkstmt(stmt, con);
   stat := psqlite_bind_int(stmt, 1, f1);
   checkstat(stat, con);
   stat := psqlite_step_nonquery(stmt);
   checkstat(stat, con);
   psqlite_finalize(stmt);
end;

var
   con : sqlite_ptr;

begin
   con := connect('test.db');
   test_getone(con, 2);
   test_getall(con);
   test_insert(con, 999, 'XXX');
   test_getall(con);
   test_delete(con, 999);
   test_getall(con);
   psqlite_close(con);
end.
